---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: timxx

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment**
 - Distribution: [e.g. Ubuntu 18.04]
 - Versions: [e.g. pywpsrpc 1.0.2, WPS Office 11.1.0.9126]
 - Installed from pip: [yes/build from source]
